eyre.utils


embedcljmacro

(embed path)
source

keywordize-statusclj

(keywordize-status status)
source

newlinesclj

source

normalize-macclj

(normalize-mac mac)

Normalizes a mac address to colon-separated lower case. Accepts colon, dash, or no separators.

Normalizes a mac address to colon-separated lower case. Accepts
colon, dash, or no separators.
sourceraw docstring

parse-kvclj

(parse-kv content)

Parses key=value lines into a keyword->string map. Surrounding double quotes are stripped from values.

Parses `key=value` lines into a keyword->string map. Surrounding
double quotes are stripped from values.
sourceraw docstring

parse-kv-colonclj

(parse-kv-colon content)

Parses key: value lines into a keyword->string map.

Parses `key: value` lines into a keyword->string map.
sourceraw docstring

parse-prefixclj

(parse-prefix p)

Parses a netmask like 255.255.255.0 or 0xffffff00 into a prefix length. If already a number string returns the int.

Parses a netmask like `255.255.255.0` or `0xffffff00` into a prefix
length. If already a number string returns the int.
sourceraw docstring

parse-sectionsclj

(parse-sections out)

Splits raw gather output into a map of section-name -> joined string. Sections are delimited by ===name=== markers.

Splits raw gather output into a map of section-name -> joined string.
Sections are delimited by `===name===` markers.
sourceraw docstring

rejoin-linesclj

(rejoin-lines lines)
source

cljdoc builds & hosts documentation for Clojure/Script libraries